@@ -1,3 +1,5 @@
+from typing import Optional
+
 from dataclasses import dataclass
 
 from valo_api.utils.init_options import InitOptions
@@ -5,5 +7,6 @@ from valo_api.utils.init_options import InitOptions
 
 @dataclass
 class ErrorResponse(InitOptions):
-    status: int
-    message: str
+    status: Optional[int] = None
+    message: Optional[str] = None
+    error: Optional[str] = None
